# floodam.agri 1.0.3.0 (2024-09-25)

## Enhancements

* `plot_damage_function()`
    * new function to plot one or more damage functions
    * documentation completed
* `plot_disaggregated_damage_function()`
    * new function to plot a disaggregated damage function
    * documentation completed
* `plot_crop_calendar()`
    * addition of `title_culture` to manage names of crops on plot
* `week_axis()` (internal used by graphical functions)
    * add a weekly label to x axis
* `round_up_nice()` (internal used by graphical functions)
    * round values nicely for plots

## Documentation

* Vignette
    * [Understanding input files](http://www.floodam.org/floodam.agri/articles/understanding_input_files.html)

## Dependencies 

- Package `kableExtra` (vignette)
- Package `scales` (vignette)

# floodam.agri 1.0.2.1 (2024-09-13)

## Enhancements

* `aggregate_damage()`
    * `hazard_agg` parameter is now a list of arrays instead of folder name.
    Default set to `floodam.agri::HAZARD_AGGREGATE`
    * `damage_origin` default change from `RPG_total` to `total`
* `plot_aggregated_damage()`
    * addition of `col` parameter to manage plot colors
* `plot_crop_calendar()`
    * addition of `col` parameter to manage plot colors
* `HAZARD_AGGREGATE` 
    * global data added (list) to simplify damage function aggregation

## Documentation

* Vignette
    * [Get started](http://www.floodam.org/floodam.agri/articles/floodam-agri.html)
        * addition of a plot of aggregated damage curves

# floodam.agri 1.0.2.0 (2024-09-12)

## Enhancements

* `combine_damaging()`
    * addition of `retrieve` argument
* `plot_aggregated_damage()`
    * replacement of `plot_agriculture_damage()`
    * addition of arguments to help usage as wanted
    * documentation completed
    * **TO DO** deal with plot legend
* `plot_agriculture_damage()`
    * removed, replaced by `plot_aggregated_damage()`
* `plot_crop_calendar()`
    * new function to plot crop calendars
    * documentation completed

## Documentation

* Vignettes
    * [Get started](http://www.floodam.org/floodam.agri/articles/floodam-agri.html)
    * [How to build the french national damage functions to the agricultural sector with floodam.agri](http://www.floodam.org/floodam.agri/articles/build_national_functions.html)
    * [Understanding path declaration with init_path()](http://www.floodam.org/floodam.agri/articles/understanding_init_path.html) (initialized) **TO DO**
    * [Understanding inputs for floodam.agri](http://www.floodam.org/floodam.agri/articles/understanding_inputs.html) (initialized) **TO DO**
* README.md
    * Introduction of key references in introduction

## Dependencies 

- Package `DT` (vignette)
- Package `knitr` (vignette)
- Package `Rmarkdown` (vignette)
- Package `RColorBrewer` (vignette)

# floodam.agri 1.0.1.0 (2024-08-23)

## Enhancements

* Some global data has been internalised in folder `data` and documented in 
`R/data.R`. It is built from files in `inst/extdata/global_data`:
    * `COMBINE` (list)
    * `CURRENT` (data.frame)
    * `HAZARD` (character vector)
    * `HAZARD_RESOLUTION` (data.frame)
    * `LEVEL` (list)
* `array_current()` (internal used by `make_curve()`)
    * documentation completed
    * renaming of `current` argument to `current_start`
    * addition of a new `current` argument
    * **TO DO: test**
* `calculate_damaging()`
    * addition of `current` argument
* `fit_complement()`(internal used by `make_curve()`)
    * addition of `current` argument
    * test added
    * documentation completed
    * warnings added
* `load_hazard()` (internal)
    * converted as internal (apparently not used, but may be useful for future
    development)
    * addition of `level` argument
    * change of `hazard` argument to `hazard_resolution`
* `make_curve()`
    * documentation completed
    * addition of `current` argument
* `plot_agricultural_damage()`
    * addition of `hazard` argument added

# floodam.agri 1.0.0.0 (2024-08-21)

This is the first version provided for installation.

## Enhancements

* All functions have been renamed to respect snake_case convention.
* All functions have at least a *basic* documentation, that may not be very
useful at this stage.
* Data has been added to the "inst/extdata" folder, with this organisation:
    * `classification` (folder in inst/extdata)
        * classification for french LPIS (RPG). `RPG.csv` is the current 
        classification while `RPG_1.csv` is the old classification.
    * `default` (folder in inst/extdata)
        * `damagement` (crop vulnerability decisions),
        `hazard` (hazard parameters),
        `stat` (action values, prices, yields),
        `typology` (correspondance tables)
        used to create the french national functions
    * `national` (folder in inst/extdata)
        * `2009-2010-2011` data used for french national functions (same as in 
        default but no `damagement` or `hazard` files)
        * `2016` national yields for the year 2016 and associated correspondance
        tables
    * `regional` (folder in inst/extdata)
        * `2016` Occitanie region yields and associated correspondance tables 
    * `example` (folder in inst/extdata)
        * data used to run tests and examples
    * **TO DO: internalise some data supported by vignettes**
* `init_path()`
    * rework of function to specify several paths where to find data with a 
    user defined priority level
    * removal of arguments `extent`, `region`, `local`, `year` and `create`
    * addition of `default` argument to specify whether missing values should be
    completed by default ones
    * addition of `classification` argument to indicate which classification
    references to use in making weights
    * addition of internal functions to help find files (
    `init_user_path()`, `find_data_path()`, `find_file_path()`,
    `find_output_files()`, `find_weight_files()`, `list_hazard_files()`)
    * addition of warnings
    * complete documentation and test added
    * **TO DO: complete tests for all internal functions**
* `prepare_culture()`
    * rework to fit new paths from `init_path()`
    * replacement of original arguments by `path` and `typo` 
    * addition of warnings
    * complete documentation and test added
    * **TO DO: keep track of the origin of vulnerability files in a log file**
* `make_weight()`
    * addition of `na.rm = TRUE` to `rowSums()` to deal with NA values
    * complete documentation and test added
* `prepare_typology()`
    * rework to fit new paths from `init_path()`
    * replacement of original arguments by `path` and `classification` 
    * addition of an internal function `treat_guideline()` for simplifications
    * addition of warnings
    * complete documentation and test added
* `prepare_calendar()`
    * rework to fit new paths from `init_path()`
    * addition of an internal function `extract_calendar()` to simplify tests
    * addition of warnings
    * complete documentation and test added
* `prepare_action_value()`
    * rework to fit new paths from `init_path()`
    * addition of internal functions `extract_calendar()` and `extract_yield()`
    to simplify tests
    * addition of warnings
    * complete documentation and test added
* `calculate_damaging()`
    * rework to fit new paths from `init_path()`
    * modification of `backup` argument to simplify the specification of desired
    output
    * addition of `simple` argument to deal with the output format used in `combine_damaging()`
    * addition of warnings
    * complete documentation and test added
    * **TO DO: deal with global variables**
    * **TO DO: tests for make_curve() or fit_calendar()**
* `combine_damaging()`
    * rework to fit new paths from `init_path()`
    * addition of `weight`argument to indicate which classification should be
    used for weights 
    * addition of `hazard` to indicate the hazard parameters
    * addition of internal functions `combine_weight()` and `rbind_list()`
    * complete documentation and test added
    * **TO DO: check if `hazard` parameter is necessary**
* `aggregate_damage()`
    * rework to fit new paths from `init_path()`
    * addition of new arguments `damage_origin`, `hazard_agg` and `retrieve`
    * addition of internal function `calculate_aggregated_damage()` to simplify
    tests
    * complete documentation and test added
* `plot_agriculture_damage()`
    * rework to fit new paths from `init_path()`
    * complete documentation
    * **TO DO: rework to allow easier customisation** 

# floodam.agri 0.1.0.1

This is the first version of the library. It has been built on the basis of the
collection of script from the archive that were used to build French official
damage functions.

This version is not provided for installation.


