#' Combine rules
#'
#' This dataset contains the calculation method for each component.
#'
#' @format A named list of 7 elements of length 1:
#' \describe{
#'      \item{damaging.plant}{character, calculation rule for damage to plant.}
#'      \item{damaging.yield}{character, calculation rule for damage to yield.}
#'      \item{damage.soil}{character, calculation rule for damage to soil.}
#'      \item{damaging.price}{character, calculation rule for price reduction.}
#'      \item{e.palissage.material}{character, calculation rule for damage
#' to trellis.}
#'      \item{e.harvestman.vine}{character, calculation rule for damage
#' to harvestman. TO BE PRECISED}
#'      \item{damage.material}{character, calculation rule for damage to 
#' material.}
#' }
"COMBINE"

#' Correspondance between velocity qualitative classes and their value in
#' `floodam.agri`
#'
#' This dataset contains numeric values corresponding to the flood velocity
#' qualitative classes.
#'
#' @format A data frame with 3 rows and 1 variable:
#' \describe{
#'      \item{value}{numeric, value given to the velocity hazard parameter.}
#' }
"CURRENT"

#' Hazard resolution
#'
#' This dataset contains min, max and resolution values for each hazard
#' parameter.
#'
#' @format A data frame with 4 rows and 4 variables:
#' \describe{
#'      \item{min}{integer, minimum value a given parameter can take.}
#'      \item{max}{integer, maximum value a given parameter can take.}
#'      \item{resolution}{integer, interval step to be considered for a given 
#' parameter.}
#' }
"HAZARD_RESOLUTION"

#' Names of hazard parameters
#'
#' This dataset give the default hazard parameters.
#'
#' @format A character vector with 4 elements.
"HAZARD"

#' Levels for each hazard parameter
#'
#' This dataset contains the detailed levels for each hazard parameter.
#'
#' @format A named list of 4 elements:
#' \describe{
#'      \item{current}{integer, current levels (qualitative, see 
#' `floodam.agri::CURRENT`).}
#'      \item{duration}{integer, duration levels (in days).}
#'      \item{height}{integer, height levels (in cm).}
#'      \item{week}{integer, week levels (in ISO week-numbering)}
#' }
"LEVEL"

#' Aggregated hazard parameters
#'
#' This dataset contains the hazard parameters to transform a raw damage 
#' function into an aggregated damage function with `aggregate_damage()`.
#'
#' @format A named list of 3 elements:
#' \describe{
#'      \item{current}{array, current intervals.}
#'      \item{duration}{array, duration intervals.}
#'      \item{week}{array, week intervals.}
#' }
"HAZARD_AGGREGATE"