#' @title Load hazard
#'
#' @description 
#' Loads hazard from a file. Its usage still needs to be understood...
#' 
#' @param x character, the name of the file which the data are to be read from.
#' @param hazard_resolution character, hazard parameters, default to
#' floodam.agri::HAZARD_RESOLUTION.
#' @param level list giving levels for hazard parameters (current, duration, 
#' height, week), default to floodam.agri::LEVEL.
#'
#' @return list, TO BE PRECISED
#'
#' @encoding UTF-8

load_hazard = function(
    x,
    hazard_resolution = floodam.agri::HAZARD_RESOLUTION,
    level = floodam.agri::LEVEL
) {
    fun = function(x) {
        if (x["hazard"] == "week") {
            v = seq_period(as.integer(x["begin"]), as.integer(x["end"]))
        } else {
            v = seq(
                as.integer(x["begin"]),
                as.integer(x["end"]),
                by = hazard_resolution[x["hazard"], "resolution"]
            )
        }
        if (x["pdf"] == "unif") {
            p = rep(1 / length(v), length(v))
        }
        if (x["pdf"] == "explicit") {
            p = as.numeric(unlist(strsplit(x["parameter"], ",")))
        }
        cbind("class" = as.integer(x["class"]), "value" = v, "prob" = p)
    }

    gun = function(x) {
        x = as.matrix(x)
        r = NULL
        for (i in seq(rownames(x))) {r = rbind(r, fun(x[i, ]))}
        return(r)
    }

    base = expand.grid(
        lapply(level, as.numeric),
        KEEP.OUT.ATTRS = FALSE,
        stringsAsFactors = FALSE
    )

    result = split(result, result[1])
    result = lapply(result, gun)
}
