#' @title Make data.frame from list
#'
#' @description
#' `make_df_from_list()` makes a data.frame from a list. This function is called 
#' in `prepare_action_value()`
#' 
#' @param x list to be transformed to data.frame
#' @param check logical, TO BE PRECISED, default to TRUE
#' @param coerce.name character, TO BE PRECISED, default to NULL
#'
#' @return data.frame
#'
#' @export
#'
#' @encoding UTF-8

make_df_from_list = function(
    x,
    check = TRUE,
    coerce.name = NULL
) {
    adapt = function(x, coerce.name, name) {
        if (!is.null(coerce.name)) x[, coerce.name] = name
        x
    }

    if (isTRUE(check)) {
        if (!all(sapply(x, is.data.frame)))
            stop("Some elements of x are not data.frame.")
        if (!all(apply(sapply(x, names), 1, function(x) {
            length(unique(x)) == 1
        })))
            stop("All elements of x are not similarly organized.")
    }

    result = adapt(x[[1]], coerce.name, names(x)[1])
    if (length(x) > 1) {
        for (i in seq(2, length(x))) {
            result = rbind(
                result,
                adapt(
                    x[[i]],
                    coerce.name,
                    names(x)[i]
                )
            )
        }
    }
    
    return(result)
}
