#' @title Make weight
#' 
#' @description
#' `make_weight()` creates weights coherently with an identity matrix, `x` and a
#' matrix giving the quantities for each crop for one or several years.
#' Called in `prepare_typology()`
#'
#' @param x identity matrix indicating the correspondance between a crop 
#' typology and another.
#' @param y matrix, quantity of each crop to be used to create weights.
#' @param weight logical, should weights be applied to result. Should be set to 
#' FALSE to return a matrix filled with values of y coherently with 
#' correspondance. Default to TRUE.
#' @param trim integer, argument passed to `mean()`, default to 0.
#' 
#' @return matrix of weights.
#'
#' @export
#'
#' @encoding UTF-8

make_weight = function(
    x,
    y,
    weight = TRUE,
    trim = 0
) {
    x[is.na(x)] = 0
    x = x / rowSums(x)

    y = y[rownames(x), ]
#~     if (length(dim(y)) == 2) y = rowSums(y, na.rm = TRUE)
    if (length(dim(y)) == 2) y = apply(
        y,
        1,
        mean,
        trim = trim / ncol(y),
        na.rm = TRUE
    )

    result = t(x * y)
    if (isTRUE(weight)) result = t(result / rowSums(result, na.rm = TRUE))

    invisible(result)
}
