## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.align = "center"
)
path_data = system.file("extdata", "vignettes", package = "floodam.agri")

## ----setup, eval = FALSE------------------------------------------------------
#  #> Loading required package: floodam.agri
#  library(floodam.agri)
#  
#  #> Setting up environment paths (inputs and outputs)
#  input = stats::setNames(
#      system.file(
#        "extdata",
#        "national",
#        "2009-2010-2011",
#        package = "floodam.agri"
#      ),
#      "national"
#  )
#  output = file.path(tempdir(), "national")
#  classification = system.file(
#    "extdata",
#    "classification",
#    package = "floodam.agri"
#  )
#  
#  path = init_path(
#    input = input,
#    output = output,
#    default = TRUE,
#    classification = classification
#  )

## ----data-preparation, eval = FALSE-------------------------------------------
#  #> Extracting damagement files to output
#  prepare_culture(path)
#  
#  #> Extracting and copying calendars to output
#  prepare_calendar(path)
#  
#  #> Building weight files
#  prepare_typology(
#    path,
#    "RPG" # name of the classification used to build weights.
#          # See `path[["classification"]][["RPG.csv"]]`
#  )
#  
#  #> Preparing necessary action values and yields
#  prepare_action_value(path)

## ----damage-function, eval = FALSE--------------------------------------------
#  #> Calculating damage function
#  damaging = calculate_damaging(
#    path,
#    culture = # set to NULL to build all damage functions
#      c("onion", "salad", "vineyard", "wheat"),
#    retrieve = TRUE
#  )
#  #> Update of culture damaging functions:
#  #>   Processing onion... Finished in 3.39 secs
#  #>   Processing salad... Finished in 3.99 secs
#  #>   Processing vineyard... Finished in 4.78 secs
#  #>   Processing wheat... Finished in 3.40 secs
#  #> ... processed in 12.17 secs

## ----damaging-sample, echo = FALSE--------------------------------------------
damaging = read.csv2(file.path(
    path_data,
    "damage-disaggregated_vineyard.csv")
)

DT::datatable(
  damaging,
  caption = "Result of `calculate_damaging()`: raw total disaggregated damage of a vineyard plot (first thousand rows).",
  rownames = FALSE,
  options = list(
    pageLength = 10, autoWidth = TRUE,
    lengthMenu = c(5, 10, 15, 20, 25, 50, 100)
  )
)

## ----combine-damage-function, eval = FALSE------------------------------------
#  #> Combine damage to new classification
#  combine = combine_damaging(
#    path = path,
#    damage.culture = damaging,
#    weight = "RPG",
#    verbose = TRUE,
#    retrieve = "total" # one of c("total", "yield.annual", "yield.differed",
#    # "replanting", "soil", material")
#  )

## ----combine-sample, echo = FALSE---------------------------------------------
combine = read.csv2(file.path(path_data, "combine.csv"))
DT::datatable(
  combine,
  caption = "Result of `combine_damaging()`: raw total damage with RPG classification (first thousand rows).",
  rownames = FALSE,
  options = list(
    pageLength = 10,
    autoWidth = TRUE,
    lengthMenu = c(5, 10, 15, 20, 25, 50, 100)
  )
)

## ----hazard-parameters, echo = FALSE------------------------------------------
hazard = readRDS(file.path(path_data, "hazard.rds"))

knitr::kables(
    list(
        knitr::kable(
            hazard[["current"]],
            caption = "Velocity"
        ),
        knitr::kable(
            hazard[["duration"]],
            caption = "Duration"
        ),
        knitr::kable(
            hazard[["week"]],
            caption = "Seasonality"
        ),
        caption = "Hazard parameters classes used in the french national damage functions."
    )
)

## ----aggregate-damage, eval = FALSE-------------------------------------------
#  #> Aggregation of damage according to the specified `hazard.00` parameters
#  agg_damaging = aggregate_damage(
#      path,
#      damage_origin = "RPG_total", # by default
#      hazard_agg = "hazard.00" # by default
#  )

## ----aggregate-sample, echo = FALSE-------------------------------------------
agg_damaging = read.csv2(file.path(path_data, "aggregated-damage.csv"))
DT::datatable(
  agg_damaging,
  caption = "Result of `aggregate_damage()`: aggregated damage with RPG classification.",
  rownames = FALSE,
  options = list(
    pageLength = 10, autoWidth = TRUE,
    lengthMenu = c(5, 10, 15, 20, 25, 50, 100)
  )
)

