% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/init_path.R
\encoding{UTF-8}
\name{init_path}
\alias{init_path}
\title{Create input and output paths}
\usage{
init_path(input, output = tempdir(), default = TRUE, classification = NULL)
}
\arguments{
\item{input}{named character vector indicating where to find inputs. This
vector defines the path where to look for files in priority. If nothing is
specified, paths will be set to `system.file("extdata", "default", package = 
"floodam.agri")`.}

\item{output}{character, path for output. Default to `tempdir()`.}

\item{default}{logical, should "default" path be created. If TRUE, "default"
path will be set to `system.file("extdata", "default", package = 
"floodam.agri")`. Default to TRUE.}

\item{classification}{character giving the path to the folder which contains
classification references. If NULL, no path is created. Default to NULL.}
}
\value{
list of character, paths created.
}
\description{
`init_path()` creates paths that will be used to find input data and save 
outputs.
}
\details{
`input` parameter:
The order of each element in `input` is important as it will define the order
in which inputs will be searched in `path[["extent"]]`.
}
\examples{

path = init_path()

# Unnamed input vector
input = c(
    system.file(
        "extdata",
        "example",
        "local",
        "winery",
        package = "floodam.agri"
    ),
    system.file(
        "extdata",
        "regional",
        "Occitanie",
        "2016",
        package = "floodam.agri"
    ),
    system.file("extdata", "national", package = "floodam.agri")
)
path = init_path(input)
print(path[["extent"]])

path = init_path(input, default = FALSE)
print(path[["extent"]])

names(input) = c("local", "regional", "national")
path = init_path(input)
print(path[["extent"]])

}
