test_that("test calculate_aggregated_damage",
    {
        detail = data.frame(
            duration = rep(1, 12),
            height = rep(50, 12),
            current = rep(1, 12),
            week = c(rep(10, 3), rep(20, 3), rep(30, 3), rep(42, 3)),
            BLE.TENDRE = seq(0, 11000, 1000),
            AUTRES.CEREALES = seq(0, 23000, 2000)
        )

        hazard = list(
            current = data.frame(
                min = 1:3,
                max = 1:3,
                row.names = c("light", "middle", "strong")
            ), 
            duration = data.frame(
                min = c(0L, 2L, 5L, 11L),
                max = c(1L, 4L, 10L, 20L),
                row.names = c("short", "middle", "long", "extra")
            ), 
            week = data.frame(
                min = c(14L, 27L, 40L, 1L), 
                max = c(26L, 39L, 52L, 13L),
                row.names = c("spring", "summer", "autumn", "winter")
            )
        )

        # Testing object type
        result = calculate_aggregated_damage(
            detail = rbind(detail, detail),
            hazard
        )
        expect_s3_class(result, "data.frame")
        
        # Testing custom periods
        expect_identical(nrow(result), nrow(hazard[["week"]]))
        hazard[["week"]] = data.frame(
            min = c(14L, 40L), 
            max = c(39L, 13L),
            row.names = c("spring-summer", "autumn-winter")
        )
        result = calculate_aggregated_damage(detail, hazard)
        expect_identical(nrow(result), nrow(hazard[["week"]]))
    
        # Adding different currents
        detail[["current"]] = rep(c(1, 2, 3), 4)
        result = calculate_aggregated_damage(detail, hazard)
        expect_identical(
            nrow(result),
            nrow(hazard[["week"]])*nrow(hazard[["current"]])
        )

        # Adding different durations
        detail[["duration"]] = rep(c(1, 3, 7, 15), 3)
        detail[["week"]] = rep(1, 12)
        detail[["current"]] = rep(1, 12)
        result = calculate_aggregated_damage(detail, hazard)

        expect_identical(
            nrow(result),
            nrow(hazard[["duration"]])
        )
    }
)