test_that("test combine_weight",
    {
        damage.culture = list(
            cereal_1 = data.frame(
                total = c(0, 100, 200, 300),
                yield.annual = c(0, 50, 100, 150),
                replanting = c(0, 20, 40, 60),
                new_component = c(0, 30, 60, 90)
            ),
            cereal_2 = data.frame(
                total = c(0, 1000, 2000, 3000),
                yield.annual = c(0, 500, 1000, 1500),
                replanting = c(0, 200, 400, 600),
                new_component = c(0, 300, 200, 900)
            ),
            vineyard = data.frame(
                total = c(0, 10000, 20000, 30000),
                yield.annual = c(0, 5000, 10000, 15000),
                replanting = c(0, 2000, 4000, 6000),
                new_component = c(0, 3000, 6000, 9000)
            ),
            wheat = data.frame(
                total = c(0, 100000, 200000, 300000),
                yield.annual = c(0, 50000, 100000, 150000),
                replanting = c(0, 20000, 40000, 60000),
                new_component = c(0, 30000, 60000, 90000)
            )
        )
        
        weight_all = list(
            regional = structure(
                c(0.8, 0.2, 0, 0, 0, 1),
                dim = c(3L, 2L),
                dimnames = list(
                    c("cereal_1", "cereal_2", "vineyard"),
                    c("CEREALS", "VINEGROWING")
                )
            ),
            national = structure(
                c(0.2, 0.8, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1),
                dim = c(4L, 3L),
                dimnames = list(
                    c("cereal_1", "cereal_2", "vineyard", "wheat"),
                    c("CEREALS", "VINEGROWING", "WHEAT")
                )
            ),
            default = structure(
                c(1, 0, 0, 1),
                dim = c(2L, 2L),
                dimnames = list(
                    c("vineyard", "wheat"),
                    c("VINEGROWING", "WHEAT")
                )
            )
        )

        action_value = list(
            cereal_1 = data.frame(
                culture = rep("cereal_1", 4), 
                name = c("task_1", "task_2", "sale.price", "yield"), 
                value = c(462, 258, 100, 80), 
                extent = rep("regional", 4)
            ),
            cereal_2 = data.frame(
                culture = rep("cereal_2", 5),
                name = c("task_1", "task_2", "task_3", "sale.price", "yield"), 
                value = c(462, 258, 100, 80, 90), 
                extent = rep("regional", 5)
            ),
            vineyard = data.frame(
                culture = rep("vineyard", 4), 
                name = c("task_1", "task_2", "sale.price", "yield"), 
                value = c(462, 258, 100, 80), 
                extent = rep("regional", 4)
            ),
            wheat = data.frame(
                culture = rep("wheat", 4), 
                name = c("task_1", "task_2", "sale.price", "yield"), 
                value = c(462, 258, 100, 80), 
                extent = c("regional", "regional", "regional", "national")
            )
        )
        
        output = combine_weight(
            weight_all,
            action_value,
            damage.culture,
            damage.component = names(damage.culture[[1]])
        )

        expect_identical(
            names(output),
            names(damage.culture[[1]])
        )
        expect_identical(
            colnames(output[[1]]),
            c("CEREALS", "VINEGROWING", "WHEAT")
        )
        expect_identical(
            output[["total"]][2, 1],
            stats::setNames(100*0.8 + 1000*0.2, "CEREALS")
        )
    }
)