
test_that("test prepare_typology",
    {
        extent = "example"
        classification = system.file(
            "extdata",
            extent,
            "example_classification",
            package = "floodam.agri"
        )
        output = file.path(tempdir(), extent)

        # Configuration 1
        ## statistical data & floodam only 
        input = c(
            extent_1 = system.file(
                "extdata",
                extent,
                "extent_1",
                package = "floodam.agri"
            )
        )
        path = init_path(
            input = input,
            output = output,
            default = FALSE,
            classification = classification
        )
        expect_silent(prepare_typology(path))
        expect_error(prepare_typology(path, classification = "LPIS"))

        lapply(path[["output"]], unlink, recursive = TRUE)

        # Configuration 2
        ## statistical data & floodam
        ## statistical data & new typology
        ## floodam & new typology

        input = c(
            input,
            extent_2 = system.file(
                "extdata",
                extent,
                "extent_2",
                package = "floodam.agri"
            )
        )
        path = init_path(
            input = input,
            output = output,
            default = FALSE,
            classification = classification
        )
        expect_error(prepare_typology(path))
        expect_silent(prepare_typology(path, classification = "example_RPG"))
        
        # Configuration 3
        ## Crops in correspondance file and classification file do not match
        
        lapply(path[["output"]], unlink, recursive = TRUE)
        
        input = c(
            input,
            extent_3 = system.file(
                "extdata",
                extent,
                "extent_3",
                package = "floodam.agri"
            )
        )
        
        path = init_path(
            input = input,
            output = output,
            default = FALSE,
            classification = classification
        )
    
        expect_error(prepare_typology(path, classification = "example_RPG"))

        lapply(path[["output"]], unlink, recursive = TRUE)

        # Configuration 4
        input = c(
            winery = system.file(
                "extdata",
                extent,
                "local",
                "winery_2",
                package = "floodam.agri"
            )
        )
        path = init_path(
            input = input,
            output = output,
            default = FALSE,
            classification = classification
        )
        expect_silent(prepare_typology(path, classification = "winery_2"))
        expect_identical(
            load_typology(
                file.path(path$output$typology, "weight.floodam.winery_2.csv")
            ),
            matrix(c(0.5, 0.5), dimnames = list(
                c("cabernet", "merlot"),
                c("VITICULTURE")
            ))
        )
        lapply(path[["output"]], unlink, recursive = TRUE)

        # Configuration 5
        input = c(
            winery = system.file(
                "extdata",
                extent,
                "local",
                "winery_3",
                package = "floodam.agri"
            )
        )
        path = init_path(
            input = input,
            output = output,
            default = FALSE,
            classification = classification
        )
        expect_error(prepare_typology(path))
    }
)